@@ -2,3 +2,6 @@ from .RV import RV
 
 from .DACE import DACE
 DACE = DACE()
+
+from .KOBE import KOBE
+KOBE = KOBE()
